pub struct CategoricalParam<T: Clone> { /* private fields */ }Expand description
A categorical parameter that selects from a list of choices.
The generic type T is the element type of the choices vector.
The sampler picks an index and the corresponding element is returned.
Examples
use optimizer::Trial;
use optimizer::parameter::{CategoricalParam, Parameter};
let mut trial = Trial::new(0);
let opt = CategoricalParam::new(vec!["sgd", "adam", "rmsprop"])
.name("optimizer")
.suggest(&mut trial)
.unwrap();Implementations
Sourceimpl<T: Clone> CategoricalParam<T>
impl<T: Clone> CategoricalParam<T>